@@ -1,11 +1,17 @@
 """Constants package for PyVSS."""
 PACKAGE_NAME = "pyvss"
 
-__version__ = '2022.3.0'
+__version__ = '2022.3.1'
 
 
 API_ENDPOINT_BASE = 'https://cloud-api.eis.utoronto.ca'
 VSS_API_WEBDAV_SERVER = 'https://vskey-stor.eis.utoronto.ca'
+
+VSS_S3_URL = 'https://vskey-stor.eis.utoronto.ca'
+VSS_S3_SVC_URL = '{s3_server}/s3/minio-svc/index.php'
+VSS_S3_STS_URL = '{s3_svc_url}?status=json'
+VSS_S3_CFG_URL = '{s3_svc_url}?config=UTvss-S3-Minio-{s3_name}-{username}.json'
+
 DEFAULT_TIMEOUT = 60
 DEFAULT_DEBUG = False
 DEFAULT_DRY_RUN = False
